# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl test.pl'

######################### We start with some black magic to print on failure.

# Change 1..1 below to 1..last_test_to_print .
# (It may become useful if the test is moved to ./t subdirectory.)

BEGIN { $| = 1; print "1..5\n"; }
END {print "not ok 1\n" unless $loaded;}
use Authen::Krb5::Easy qw{kinit kerror kexpires kdestroy kcheck kexpired};
$loaded = 1;
print "ok 1\n";

######################### End of black magic.

# Insert your test code below (better if it prints "ok 13"
# (correspondingly "not ok 13") depending on the success of chunk 13
# of the test code):

print "Enter keytab file (or 'none' to skip further tests): ";
my $keytab = <STDIN>;
chomp($keytab);
if($keytab eq "none")
{
	exit(0);
}
print "Enter principle to use: ";
my $princ = <STDIN>;
chomp($princ);

print "kinit ";
if(kinit($keytab, $princ))
{
	print "ok 2\n";
}
else
{
	print "not ok 2\n";
	print "\terror was: " . kerror();
}

print "kexpired ";
if(kexpired())
{
	print "not ok 3\n";
	print "\tticket already expired?\n";
}
else
{
	print "ok 3\n";
}

print "kdestroy ";
if(!kdestroy())
{
	print "not ok 4\n";
	print "\terror was: " . kerror();
}
else
{
	print "ok 4\n";
}

print "kexpires ";
if(kexpires() != 0)
{
	print "not ok 5\n";
}
else
{
	print "ok 5\n";
}
